@@ -4,6 +4,7 @@ from __future__ import division
 __author__ = 'Torindo Nesci'
 
 import sys
+import traceback
 from time import sleep
 import errno
 from os import stat
@@ -150,7 +151,7 @@ class Tail:
     try:
       file.close()
     except Exception as ex:
-      log('An exception occurred while trying to close the file: {0}.', str(ex))
+      log('An exception occurred while trying to close the file: {0}.', repr(ex))
 
   def log_tail(self):
     wait_interval = MIN_WAIT
@@ -165,7 +166,7 @@ class Tail:
         self.file.seek(self.pos)
       else:
         str = bytes.decode(self.charset)
-        log('Read {0}', str)
+        log('Read {0}', bytes)
         yield str
         self.size += len(bytes)
         wait_interval = MIN_WAIT
@@ -200,5 +201,6 @@ def slicklog_tail(logfile, api_key, log_group_name, log_name, endpoint, suppress
     try:
       _slicklog_tail(remote_logger, tail, suppress_print, charset)
     except Exception as ex:
-      log('An error occurred while running {0}: {1}', __TOOL_NAME, str(ex))
+      ex_format = traceback.format_exc()
+      log('An error occurred while running {0}: {1} / {2}', __TOOL_NAME, str(ex), ex_format)
       wait_interval = _wait(wait_interval)
